@@ -1,7 +1,7 @@
 # $Author: ddumont $
-# $Date: 2006/12/07 13:13:22 $
+# $Date: 2007/06/07 16:49:58 $
 # $Name:  $
-# $Revision: 1.1 $
+# $Revision: 1.2 $
 
 #    Copyright (c) 2005,2006 Dominique Dumont.
 #
@@ -35,7 +35,7 @@
       'Driver'         => { type       => 'leaf',
 			    value_type => 'enum',
 			    mandatory  => 1 ,
-			    choice => [qw/keyboard mouse/] ,
+			    choice => [qw/keyboard kbd mouse/] ,
 			  },
       [qw/SendCoreEvents HistorySize/]
                        => { type       => 'leaf',
@@ -44,11 +44,12 @@
       => { type     => 'warped_node',
 	   follow   => '- Driver',
 	   'rules' 
-	   => { 'keyboard' 
+	   => [
+	       [qw/keyboard kbd/] 
 		=> { config_class_name => 'Xorg::InputDevice::KeyboardOpt' },
 		'mouse' 
 		=> { config_class_name => 'Xorg::InputDevice::MouseOpt' },
-	      }
+	      ]
 	 },
      ],
 
